==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/sr-CS/auth/message.php <==
<?php

return array(

    'account_already_exists' => 'Nalog sa ovom e-poštom već postoji.',
    'account_not_found'      => 'Korisničko ime ili lozinka nisu ispravni.',
    'account_not_activated'  => 'Ovaj korisnički nalog nije aktiviran.',
    'account_suspended'      => 'Ovaj je korisnički nalog je blokiran.',
    'account_banned'         => 'Ovaj je korisnički nalog je zabranjen.',
    'throttle'               => 'Too many failed login attempts. Please try again in :minutes minutes.',

    'two_factor' => array(
        'already_enrolled'      => 'Your device is already enrolled.',
        'success'               => 'You have successfully logged in.',
        'code_required'         => 'Two-factor code is required.',
        'invalid_code'          => 'Two-factor code is invalid.',
    ),

    'signin' => array(
        'error'   => 'Došlo je do problema prilikom pokušaja prijavljivanja, pokušajte ponovo.',
        'success' => 'Uspešno ste se prijavili.',
    ),

    'logout' => array(
        'error'   => 'There was a problem while trying to log you out, please try again.',
        'success' => 'You have successfully logged out.',
    ),

    'signup' => array(
        'error'   => 'Došlo je do problema prilikom pokušaja kreiranja naloga, pokušajte ponovo.',
        'success' => 'Nalog je uspešno kreiran.',
    ),

    'forgot-password' => array(
        'error'   => 'Pojavio se problem prilikom pokušaja ponovnog unosa lozinke, pokušajte ponovo.',
        'success' => 'If that email address exists in our system, a password recovery email has been sent.',
    ),

    'forgot-password-confirm' => array(
        'error'   => 'Problem prilikom resetovanja lozinke, pokušajte ponovo.',
        'success' => 'Vaša je lozinka uspešno resetovana.',
    ),


);

==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/sr-CS/auth/message.php <==
<?php

return array(

    'account_already_exists' => 'Nalog sa ovom e-poštom već postoji.',
    'account_not_found'      => 'Korisničko ime ili lozinka nisu ispravni.',
    'account_not_activated'  => 'Ovaj korisnički nalog nije aktiviran.',
    'account_suspended'      => 'Ovaj je korisnički nalog je blokiran.',
    'account_banned'         => 'Ovaj je korisnički nalog je zabranjen.',
    'throttle'               => 'Previše neuspelih pokušaja. Pokušajte ponovo za :seconds sekundi.',

    'two_factor' => array(
        'already_enrolled'      => 'Vaš uređaj je već registrovan.',
        'success'               => 'Uspešno ste se prijavili.',
        'code_required'         => 'Potreban je dvofaktorski kod.',
        'invalid_code'          => 'Dvofaktorski kod je nevažeći.',
        'enter_two_factor_code' => 'Molim vas unesite vaš kod za dvofaktorsku autentifikaciju.',
        'please_enroll'         => 'Molim vas prijavite uređaj za dvofaktorsku autentifikaciju.',
    ),

    'signin' => array(
        'error'   => 'Došlo je do problema prilikom pokušaja prijavljivanja, pokušajte ponovo.',
        'success' => 'Uspešno ste se prijavili.',
    ),

    'logout' => array(
        'error'   => 'Došlo je do problema prilikom pokušaja prijavljivanja, pokušajte ponovo.',
        'success' => 'Uspešno ste se odjavili.',
    ),

    'signup' => array(
        'error'   => 'Došlo je do problema prilikom pokušaja kreiranja naloga, pokušajte ponovo.',
        'success' => 'Nalog je uspešno kreiran.',
    ),

    'forgot-password' => array(
        'error'   => 'Pojavio se problem prilikom pokušaja ponovnog unosa lozinke, pokušajte ponovo.',
        'success' => 'Uspešno: Ako ta adresa e-pošte već postoji u našem sistemu, e-poruka za povraćaj lozinke je poslata.',
    ),

    'forgot-password-confirm' => array(
        'error'   => 'Problem prilikom resetovanja lozinke, pokušajte ponovo.',
        'success' => 'Vaša je lozinka uspešno resetovana.',
    ),


);
